diff --git a/Assets/PerfectWorld/Prefab/UIManager.prefab b/Assets/PerfectWorld/Prefab/UIManager.prefab
index b29658440c..b445272f96 100644
--- a/Assets/PerfectWorld/Prefab/UIManager.prefab
+++ b/Assets/PerfectWorld/Prefab/UIManager.prefab
@@ -311,7 +311,7 @@ GameObject:
m_Icon: {fileID: 0}
m_NavMeshLayer: 0
m_StaticEditorFlags: 0
- m_IsActive: 0
+ m_IsActive: 1
--- !u!224 &1572942396405590444
RectTransform:
m_ObjectHideFlags: 0
@@ -325,11 +325,12 @@ RectTransform:
m_ConstrainProportionsScale: 0
m_Children:
- {fileID: 3145908486618148274}
+ - {fileID: 8257803607116725528}
m_Father: {fileID: 3483809415181351540}
m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
m_AnchorMin: {x: 1, y: 0}
m_AnchorMax: {x: 1, y: 0}
- m_AnchoredPosition: {x: -718.8898, y: 36.854492}
+ m_AnchoredPosition: {x: -836.66, y: 36.854492}
m_SizeDelta: {x: 50, y: 50}
m_Pivot: {x: 0.5, y: 0.5}
--- !u!222 &6524368999182548347
@@ -353,7 +354,7 @@ MonoBehaviour:
m_Name:
m_EditorClassIdentifier:
m_Material: {fileID: 0}
- m_Color: {r: 1, g: 1, b: 1, a: 1}
+ m_Color: {r: 0.14122522, g: 1, b: 0, a: 1}
m_RaycastTarget: 1
m_RaycastPadding: {x: 0, y: 0, z: 0, w: 0}
m_Maskable: 1
@@ -414,9 +415,9 @@ MonoBehaviour:
m_OnClick:
m_PersistentCalls:
m_Calls:
- - m_Target: {fileID: 5524716397471040484}
+ - m_Target: {fileID: 1890210201668811196}
m_TargetAssemblyTypeName: CECUIManager, Assembly-CSharp
- m_MethodName:
+ m_MethodName: OnChangeSkillShortcut
m_Mode: 1
m_Arguments:
m_ObjectArgument: {fileID: 0}
@@ -773,6 +774,142 @@ MonoBehaviour:
m_hasFontAssetChanged: 0
m_baseMaterial: {fileID: 0}
m_maskOffset: {x: 0, y: 0, z: 0, w: 0}
+--- !u!1 &649076494997171084
+GameObject:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ serializedVersion: 6
+ m_Component:
+ - component: {fileID: 8257803607116725528}
+ - component: {fileID: 395061354651865565}
+ - component: {fileID: 4774016234956462677}
+ m_Layer: 5
+ m_Name: Label
+ m_TagString: Untagged
+ m_Icon: {fileID: 0}
+ m_NavMeshLayer: 0
+ m_StaticEditorFlags: 0
+ m_IsActive: 1
+--- !u!224 &8257803607116725528
+RectTransform:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 649076494997171084}
+ m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
+ m_LocalPosition: {x: 0, y: 0, z: 0}
+ m_LocalScale: {x: 1, y: 1, z: 1}
+ m_ConstrainProportionsScale: 0
+ m_Children: []
+ m_Father: {fileID: 1572942396405590444}
+ m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
+ m_AnchorMin: {x: 0.5, y: 0.5}
+ m_AnchorMax: {x: 0.5, y: 0.5}
+ m_AnchoredPosition: {x: 0, y: -25}
+ m_SizeDelta: {x: 135.5798, y: 17.8015}
+ m_Pivot: {x: 0.5, y: 0.5}
+--- !u!222 &395061354651865565
+CanvasRenderer:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 649076494997171084}
+ m_CullTransparentMesh: 1
+--- !u!114 &4774016234956462677
+MonoBehaviour:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 649076494997171084}
+ m_Enabled: 1
+ m_EditorHideFlags: 0
+ m_Script: {fileID: 11500000, guid: f4688fdb7df04437aeb418b961361dc5, type: 3}
+ m_Name:
+ m_EditorClassIdentifier:
+ m_Material: {fileID: 0}
+ m_Color: {r: 1, g: 1, b: 1, a: 1}
+ m_RaycastTarget: 0
+ m_RaycastPadding: {x: 0, y: 0, z: 0, w: 0}
+ m_Maskable: 1
+ m_OnCullStateChanged:
+ m_PersistentCalls:
+ m_Calls: []
+ m_text: Change (!combo)
+ m_isRightToLeft: 0
+ m_fontAsset: {fileID: 11400000, guid: 8f586378b4e144a9851e7b34d9b748ee, type: 2}
+ m_sharedMaterial: {fileID: 2180264, guid: 8f586378b4e144a9851e7b34d9b748ee, type: 2}
+ m_fontSharedMaterials: []
+ m_fontMaterial: {fileID: 0}
+ m_fontMaterials: []
+ m_fontColor32:
+ serializedVersion: 2
+ rgba: 4292542463
+ m_fontColor: {r: 1, g: 1, b: 0.85490197, a: 1}
+ m_enableVertexGradient: 0
+ m_colorMode: 3
+ m_fontColorGradient:
+ topLeft: {r: 1, g: 1, b: 1, a: 1}
+ topRight: {r: 1, g: 1, b: 1, a: 1}
+ bottomLeft: {r: 1, g: 1, b: 1, a: 1}
+ bottomRight: {r: 1, g: 1, b: 1, a: 1}
+ m_fontColorGradientPreset: {fileID: 0}
+ m_spriteAsset: {fileID: 0}
+ m_tintAllSprites: 0
+ m_StyleSheet: {fileID: 0}
+ m_TextStyleHashCode: -1183493901
+ m_overrideHtmlColors: 0
+ m_faceColor:
+ serializedVersion: 2
+ rgba: 4294967295
+ m_fontSize: 17.02
+ m_fontSizeBase: 36
+ m_fontWeight: 400
+ m_enableAutoSizing: 1
+ m_fontSizeMin: 17.02
+ m_fontSizeMax: 72
+ m_fontStyle: 0
+ m_HorizontalAlignment: 1
+ m_VerticalAlignment: 256
+ m_textAlignment: 65535
+ m_characterSpacing: 0
+ m_wordSpacing: 0
+ m_lineSpacing: 0
+ m_lineSpacingMax: 0
+ m_paragraphSpacing: 0
+ m_charWidthMaxAdj: 0
+ m_TextWrappingMode: 1
+ m_wordWrappingRatios: 0.4
+ m_overflowMode: 0
+ m_linkedTextComponent: {fileID: 0}
+ parentLinkedComponent: {fileID: 0}
+ m_enableKerning: 0
+ m_ActiveFontFeatures: 6e72656b
+ m_enableExtraPadding: 0
+ checkPaddingRequired: 0
+ m_isRichText: 1
+ m_EmojiFallbackSupport: 1
+ m_parseCtrlCharacters: 1
+ m_isOrthographic: 1
+ m_isCullingEnabled: 0
+ m_horizontalMapping: 0
+ m_verticalMapping: 0
+ m_uvLineOffset: 0
+ m_geometrySortingOrder: 0
+ m_IsTextObjectScaleStatic: 0
+ m_VertexBufferAutoSizeReduction: 0
+ m_useMaxVisibleDescender: 1
+ m_pageToDisplay: 1
+ m_margin: {x: 0, y: 0, z: 0, w: 0}
+ m_isUsingLegacyAnimationComponent: 0
+ m_isVolumetricText: 0
+ m_hasFontAssetChanged: 0
+ m_baseMaterial: {fileID: 0}
+ m_maskOffset: {x: 0, y: 0, z: 0, w: 0}
--- !u!1 &806379414455135824
GameObject:
m_ObjectHideFlags: 0
@@ -3088,93 +3225,6 @@ MonoBehaviour:
m_OnClick:
m_PersistentCalls:
m_Calls: []
---- !u!1 &3145151337062537045
-GameObject:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- serializedVersion: 6
- m_Component:
- - component: {fileID: 6043229071629548389}
- - component: {fileID: 8897354488523566913}
- - component: {fileID: 6641354772682251721}
- - component: {fileID: 4636610088449766818}
- m_Layer: 5
- m_Name: Panel (1)
- m_TagString: Untagged
- m_Icon: {fileID: 0}
- m_NavMeshLayer: 0
- m_StaticEditorFlags: 0
- m_IsActive: 1
---- !u!224 &6043229071629548389
-RectTransform:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 3145151337062537045}
- m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
- m_LocalPosition: {x: 0, y: 0, z: 0}
- m_LocalScale: {x: 1, y: 1, z: 1}
- m_ConstrainProportionsScale: 0
- m_Children:
- - {fileID: 3398686482168957051}
- m_Father: {fileID: 2907261990866691440}
- m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
- m_AnchorMin: {x: 0, y: 1}
- m_AnchorMax: {x: 0, y: 1}
- m_AnchoredPosition: {x: 133.1923, y: -138.03845}
- m_SizeDelta: {x: 0, y: 11}
- m_Pivot: {x: 0, y: 0.5}
---- !u!222 &8897354488523566913
-CanvasRenderer:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 3145151337062537045}
- m_CullTransparentMesh: 1
---- !u!114 &6641354772682251721
-MonoBehaviour:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 3145151337062537045}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: 30649d3a9faa99c48a7b1166b86bf2a0, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- m_Padding:
- m_Left: 0
- m_Right: 0
- m_Top: 0
- m_Bottom: 0
- m_ChildAlignment: 0
- m_Spacing: 25
- m_ChildForceExpandWidth: 1
- m_ChildForceExpandHeight: 1
- m_ChildControlWidth: 0
- m_ChildControlHeight: 0
- m_ChildScaleWidth: 0
- m_ChildScaleHeight: 0
- m_ReverseArrangement: 0
---- !u!114 &4636610088449766818
-MonoBehaviour:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 3145151337062537045}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: 3245ec927659c4140ac4f8d17403cc18, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- m_HorizontalFit: 2
- m_VerticalFit: 0
--- !u!1 &2972042736830348811
GameObject:
m_ObjectHideFlags: 0
@@ -5500,91 +5550,6 @@ MonoBehaviour:
m_hasFontAssetChanged: 0
m_baseMaterial: {fileID: 0}
m_maskOffset: {x: 0, y: 0, z: 0, w: 0}
---- !u!1 &5660449539578156176
-GameObject:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- serializedVersion: 6
- m_Component:
- - component: {fileID: 3398686482168957051}
- - component: {fileID: 1842104915118890975}
- m_Layer: 5
- m_Name: BuffIconTemplate
- m_TagString: Untagged
- m_Icon: {fileID: 0}
- m_NavMeshLayer: 0
- m_StaticEditorFlags: 0
- m_IsActive: 1
---- !u!224 &3398686482168957051
-RectTransform:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 5660449539578156176}
- m_LocalRotation: {x: 0, y: 0, z: 0, w: 1}
- m_LocalPosition: {x: 0, y: 0, z: 0}
- m_LocalScale: {x: 1, y: 1, z: 1}
- m_ConstrainProportionsScale: 0
- m_Children:
- - {fileID: 1981227458035550263}
- m_Father: {fileID: 6043229071629548389}
- m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
- m_AnchorMin: {x: 0, y: 0}
- m_AnchorMax: {x: 0, y: 0}
- m_AnchoredPosition: {x: 0, y: 0}
- m_SizeDelta: {x: 20, y: 20}
- m_Pivot: {x: 0.5, y: 0.5}
---- !u!114 &1842104915118890975
-MonoBehaviour:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 5660449539578156176}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: 9085046f02f69544eb97fd06b6048fe2, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- m_Navigation:
- m_Mode: 3
- m_WrapAround: 0
- m_SelectOnUp: {fileID: 0}
- m_SelectOnDown: {fileID: 0}
- m_SelectOnLeft: {fileID: 0}
- m_SelectOnRight: {fileID: 0}
- m_Transition: 1
- m_Colors:
- m_NormalColor: {r: 1, g: 1, b: 1, a: 1}
- m_HighlightedColor: {r: 0.9607843, g: 0.9607843, b: 0.9607843, a: 1}
- m_PressedColor: {r: 0.78431374, g: 0.78431374, b: 0.78431374, a: 1}
- m_SelectedColor: {r: 0.9607843, g: 0.9607843, b: 0.9607843, a: 1}
- m_DisabledColor: {r: 0.78431374, g: 0.78431374, b: 0.78431374, a: 0.5019608}
- m_ColorMultiplier: 1
- m_FadeDuration: 0.1
- m_SpriteState:
- m_HighlightedSprite: {fileID: 0}
- m_PressedSprite: {fileID: 0}
- m_SelectedSprite: {fileID: 0}
- m_DisabledSprite: {fileID: 0}
- m_AnimationTriggers:
- m_NormalTrigger: Normal
- m_HighlightedTrigger: Highlighted
- m_PressedTrigger: Pressed
- m_SelectedTrigger: Selected
- m_DisabledTrigger: Disabled
- m_Interactable: 0
- m_TargetGraphic: {fileID: 6439321167819050832}
- toggleTransition: 1
- graphic: {fileID: 9050570107400886858}
- m_Group: {fileID: 0}
- onValueChanged:
- m_PersistentCalls:
- m_Calls: []
- m_IsOn: 1
--- !u!1 &5727863043411723117
GameObject:
m_ObjectHideFlags: 0
@@ -6621,6 +6586,142 @@ MonoBehaviour:
m_OnClick:
m_PersistentCalls:
m_Calls: []
+--- !u!1 &6476292694509891894
+GameObject:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ serializedVersion: 6
+ m_Component:
+ - component: {fileID: 884968717674151123}
+ - component: {fileID: 8951219508660711815}
+ - component: {fileID: 8940304115795854860}
+ m_Layer: 5
+ m_Name: Label
+ m_TagString: Untagged
+ m_Icon: {fileID: 0}
+ m_NavMeshLayer: 0
+ m_StaticEditorFlags: 0
+ m_IsActive: 1
+--- !u!224 &884968717674151123
+RectTransform:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 6476292694509891894}
+ m_LocalRotation: {x: 0, y: 0, z: 0, w: 1}
+ m_LocalPosition: {x: 0, y: 0, z: 0}
+ m_LocalScale: {x: 1, y: 1, z: 1}
+ m_ConstrainProportionsScale: 0
+ m_Children: []
+ m_Father: {fileID: 7592287337898200118}
+ m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
+ m_AnchorMin: {x: 0.5, y: 0.5}
+ m_AnchorMax: {x: 0.5, y: 0.5}
+ m_AnchoredPosition: {x: 0, y: -26.2}
+ m_SizeDelta: {x: 55.28, y: 14}
+ m_Pivot: {x: 0.5, y: 0.5}
+--- !u!222 &8951219508660711815
+CanvasRenderer:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 6476292694509891894}
+ m_CullTransparentMesh: 1
+--- !u!114 &8940304115795854860
+MonoBehaviour:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 6476292694509891894}
+ m_Enabled: 1
+ m_EditorHideFlags: 0
+ m_Script: {fileID: 11500000, guid: f4688fdb7df04437aeb418b961361dc5, type: 3}
+ m_Name:
+ m_EditorClassIdentifier:
+ m_Material: {fileID: 0}
+ m_Color: {r: 1, g: 1, b: 1, a: 1}
+ m_RaycastTarget: 0
+ m_RaycastPadding: {x: 0, y: 0, z: 0, w: 0}
+ m_Maskable: 1
+ m_OnCullStateChanged:
+ m_PersistentCalls:
+ m_Calls: []
+ m_text: Rotate
+ m_isRightToLeft: 0
+ m_fontAsset: {fileID: 11400000, guid: 8f586378b4e144a9851e7b34d9b748ee, type: 2}
+ m_sharedMaterial: {fileID: 2180264, guid: 8f586378b4e144a9851e7b34d9b748ee, type: 2}
+ m_fontSharedMaterials: []
+ m_fontMaterial: {fileID: 0}
+ m_fontMaterials: []
+ m_fontColor32:
+ serializedVersion: 2
+ rgba: 4292542463
+ m_fontColor: {r: 1, g: 1, b: 0.85490197, a: 1}
+ m_enableVertexGradient: 0
+ m_colorMode: 3
+ m_fontColorGradient:
+ topLeft: {r: 1, g: 1, b: 1, a: 1}
+ topRight: {r: 1, g: 1, b: 1, a: 1}
+ bottomLeft: {r: 1, g: 1, b: 1, a: 1}
+ bottomRight: {r: 1, g: 1, b: 1, a: 1}
+ m_fontColorGradientPreset: {fileID: 0}
+ m_spriteAsset: {fileID: 0}
+ m_tintAllSprites: 0
+ m_StyleSheet: {fileID: 0}
+ m_TextStyleHashCode: -1183493901
+ m_overrideHtmlColors: 0
+ m_faceColor:
+ serializedVersion: 2
+ rgba: 4294967295
+ m_fontSize: 18
+ m_fontSizeBase: 36
+ m_fontWeight: 400
+ m_enableAutoSizing: 1
+ m_fontSizeMin: 18
+ m_fontSizeMax: 72
+ m_fontStyle: 0
+ m_HorizontalAlignment: 1
+ m_VerticalAlignment: 256
+ m_textAlignment: 65535
+ m_characterSpacing: 0
+ m_wordSpacing: 0
+ m_lineSpacing: 0
+ m_lineSpacingMax: 0
+ m_paragraphSpacing: 0
+ m_charWidthMaxAdj: 0
+ m_TextWrappingMode: 1
+ m_wordWrappingRatios: 0.4
+ m_overflowMode: 0
+ m_linkedTextComponent: {fileID: 0}
+ parentLinkedComponent: {fileID: 0}
+ m_enableKerning: 0
+ m_ActiveFontFeatures: 6e72656b
+ m_enableExtraPadding: 0
+ checkPaddingRequired: 0
+ m_isRichText: 1
+ m_EmojiFallbackSupport: 1
+ m_parseCtrlCharacters: 1
+ m_isOrthographic: 1
+ m_isCullingEnabled: 0
+ m_horizontalMapping: 0
+ m_verticalMapping: 0
+ m_uvLineOffset: 0
+ m_geometrySortingOrder: 0
+ m_IsTextObjectScaleStatic: 0
+ m_VertexBufferAutoSizeReduction: 0
+ m_useMaxVisibleDescender: 1
+ m_pageToDisplay: 1
+ m_margin: {x: 0, y: 0, z: 0, w: 0}
+ m_isUsingLegacyAnimationComponent: 0
+ m_isVolumetricText: 0
+ m_hasFontAssetChanged: 0
+ m_baseMaterial: {fileID: 0}
+ m_maskOffset: {x: 0, y: 0, z: 0, w: 0}
--- !u!1 &6647846787028180792
GameObject:
m_ObjectHideFlags: 0
@@ -6880,8 +6981,9 @@ MonoBehaviour:
canvasDlg: {fileID: 7894129013412138377}
btnSecondClick: {fileID: 1330222957695115484}
m_pDlgQuickBar1: {fileID: 8338623026378970694}
+ ChangeSkillShortcutButton: {fileID: 335905991743982376}
m_pDlgSkillSubOther: {fileID: 2431558109419737109}
- m_pDlgSkillAction: {fileID: 0}
+ m_pDlgSkillAction: {fileID: 6678802354138057098}
--- !u!114 &6678802354138057098
MonoBehaviour:
m_ObjectHideFlags: 0
@@ -7599,96 +7701,6 @@ MonoBehaviour:
serializedVersion: 2
m_Bits: 64
_target: {x: 0, y: 0, z: 0}
---- !u!1 &7746906954344287823
-GameObject:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- serializedVersion: 6
- m_Component:
- - component: {fileID: 1981227458035550263}
- - component: {fileID: 4097851417846484165}
- - component: {fileID: 6439321167819050832}
- - component: {fileID: 8747785297530793900}
- m_Layer: 5
- m_Name: Background
- m_TagString: Untagged
- m_Icon: {fileID: 0}
- m_NavMeshLayer: 0
- m_StaticEditorFlags: 0
- m_IsActive: 1
---- !u!224 &1981227458035550263
-RectTransform:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 7746906954344287823}
- m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
- m_LocalPosition: {x: 0, y: 0, z: 0}
- m_LocalScale: {x: 1, y: 1, z: 1}
- m_ConstrainProportionsScale: 0
- m_Children:
- - {fileID: 517760555680850813}
- m_Father: {fileID: 3398686482168957051}
- m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
- m_AnchorMin: {x: 0, y: 1}
- m_AnchorMax: {x: 0, y: 1}
- m_AnchoredPosition: {x: 10, y: -10}
- m_SizeDelta: {x: 20, y: 20}
- m_Pivot: {x: 0.5, y: 0.5}
---- !u!222 &4097851417846484165
-CanvasRenderer:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 7746906954344287823}
- m_CullTransparentMesh: 1
---- !u!114 &6439321167819050832
-MonoBehaviour:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 7746906954344287823}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: fe87c0e1cc204ed48ad3b37840f39efc, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- m_Material: {fileID: 0}
- m_Color: {r: 1, g: 1, b: 1, a: 1}
- m_RaycastTarget: 1
- m_RaycastPadding: {x: 0, y: 0, z: 0, w: 0}
- m_Maskable: 1
- m_OnCullStateChanged:
- m_PersistentCalls:
- m_Calls: []
- m_Sprite: {fileID: 10913, guid: 0000000000000000f000000000000000, type: 0}
- m_Type: 0
- m_PreserveAspect: 0
- m_FillCenter: 1
- m_FillMethod: 4
- m_FillAmount: 1
- m_FillClockwise: 1
- m_FillOrigin: 0
- m_UseSpriteMesh: 0
- m_PixelsPerUnitMultiplier: 1
---- !u!114 &8747785297530793900
-MonoBehaviour:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 7746906954344287823}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: 31a19414c41e5ae4aae2af33fee712f6, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- m_ShowMaskGraphic: 1
--- !u!1 &7786113674810984593
GameObject:
m_ObjectHideFlags: 0
@@ -7854,6 +7866,7 @@ RectTransform:
m_ConstrainProportionsScale: 0
m_Children:
- {fileID: 4270554191894319769}
+ - {fileID: 884968717674151123}
m_Father: {fileID: 9056141770234008732}
m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
m_AnchorMin: {x: 1, y: 0}
@@ -7955,81 +7968,6 @@ MonoBehaviour:
m_StringArgument:
m_BoolArgument: 0
m_CallState: 2
---- !u!1 &8023737739092455618
-GameObject:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- serializedVersion: 6
- m_Component:
- - component: {fileID: 517760555680850813}
- - component: {fileID: 5738248052492871013}
- - component: {fileID: 9050570107400886858}
- m_Layer: 5
- m_Name: Checkmark
- m_TagString: Untagged
- m_Icon: {fileID: 0}
- m_NavMeshLayer: 0
- m_StaticEditorFlags: 0
- m_IsActive: 1
---- !u!224 &517760555680850813
-RectTransform:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 8023737739092455618}
- m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
- m_LocalPosition: {x: 0, y: 0, z: 0}
- m_LocalScale: {x: 1, y: 1, z: 1}
- m_ConstrainProportionsScale: 0
- m_Children: []
- m_Father: {fileID: 1981227458035550263}
- m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
- m_AnchorMin: {x: 0.5, y: 0.5}
- m_AnchorMax: {x: 0.5, y: 0.5}
- m_AnchoredPosition: {x: 0, y: 0}
- m_SizeDelta: {x: 20, y: 20}
- m_Pivot: {x: 0.5, y: 0.5}
---- !u!222 &5738248052492871013
-CanvasRenderer:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 8023737739092455618}
- m_CullTransparentMesh: 1
---- !u!114 &9050570107400886858
-MonoBehaviour:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 8023737739092455618}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: fe87c0e1cc204ed48ad3b37840f39efc, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- m_Material: {fileID: 0}
- m_Color: {r: 1, g: 1, b: 1, a: 1}
- m_RaycastTarget: 1
- m_RaycastPadding: {x: 0, y: 0, z: 0, w: 0}
- m_Maskable: 1
- m_OnCullStateChanged:
- m_PersistentCalls:
- m_Calls: []
- m_Sprite: {fileID: -2152444580018807177, guid: 7c25a5fa6c0f21a4293b99a5a43b5441, type: 3}
- m_Type: 0
- m_PreserveAspect: 0
- m_FillCenter: 1
- m_FillMethod: 4
- m_FillAmount: 1
- m_FillClockwise: 1
- m_FillOrigin: 0
- m_UseSpriteMesh: 0
- m_PixelsPerUnitMultiplier: 1
--- !u!1 &8053295555211033310
GameObject:
m_ObjectHideFlags: 0
@@ -15174,6 +15112,14 @@ PrefabInstance:
propertyPath: m_btnOpenCharacter
value:
objectReference: {fileID: 3803409312124193147}
+ - target: {fileID: 3414706020273276291, guid: 76408ccdbeb4c654291462fcff24a8c5, type: 3}
+ propertyPath: m_Type
+ value: 3
+ objectReference: {fileID: 0}
+ - target: {fileID: 3414706020273276291, guid: 76408ccdbeb4c654291462fcff24a8c5, type: 3}
+ propertyPath: m_FillMethod
+ value: 0
+ objectReference: {fileID: 0}
- target: {fileID: 3450976418008317958, guid: 76408ccdbeb4c654291462fcff24a8c5, type: 3}
propertyPath: m_AnchoredPosition.x
value: 3.0769196
@@ -15198,6 +15144,14 @@ PrefabInstance:
propertyPath: m_Name
value: HUDPlayer
objectReference: {fileID: 0}
+ - target: {fileID: 5335503683694560306, guid: 76408ccdbeb4c654291462fcff24a8c5, type: 3}
+ propertyPath: m_Type
+ value: 3
+ objectReference: {fileID: 0}
+ - target: {fileID: 5335503683694560306, guid: 76408ccdbeb4c654291462fcff24a8c5, type: 3}
+ propertyPath: m_FillMethod
+ value: 0
+ objectReference: {fileID: 0}
- target: {fileID: 6806681442789174374, guid: 76408ccdbeb4c654291462fcff24a8c5, type: 3}
propertyPath: m_Pivot.x
value: 0
diff --git a/Assets/Scripts/CECUIManager.cs b/Assets/Scripts/CECUIManager.cs
index 4b2cb79795..309ebe5fe2 100644
--- a/Assets/Scripts/CECUIManager.cs
+++ b/Assets/Scripts/CECUIManager.cs
@@ -31,6 +31,7 @@ public class CECUIManager : MonoSingleton
[SerializeField] private UnityEngine.UI.Button btnSecondClick;
[SerializeField] CDlgQuickBar m_pDlgQuickBar1;
+ [SerializeField] GameObject ChangeSkillShortcutButton;
public CDlgSkillSubOther m_pDlgSkillSubOther;
CDlgMessageBox m_pDlgMessageBox;
public CDlgSkillAction m_pDlgSkillAction;
@@ -61,6 +62,11 @@ public class CECUIManager : MonoSingleton
}
ShowUI("Win_Hpmpxp");
+ #if UNITY_EDITOR
+ ChangeSkillShortcutButton.SetActive(true);
+ #else
+ ChangeSkillShortcutButton.SetActive(false);
+ #endif
}
private void Update()
diff --git a/Assets/Scripts/CECHostPlayer.Skill.cs b/Assets/Scripts/CECHostPlayer.Skill.cs
index 9fe66f5018..80c8284057 100644
--- a/Assets/Scripts/CECHostPlayer.Skill.cs
+++ b/Assets/Scripts/CECHostPlayer.Skill.cs
@@ -1819,9 +1819,9 @@ namespace BrewMonster
#if UNITY_EDITOR
///
/// Cycles through learned skills by removing all shortcuts and adding 2 new skills to slots 0 and 1.
/// If m_startingSkillID is set (>0), uses that specific skill ID and the next one (ID+1).
/// Otherwise, cycles through all learned skills in pairs.
///
public void CycleSkillShortcuts()
{
@@ -1843,71 +1843,31 @@ namespace BrewMonster
// First press: startingID + 0, startingID + 1 (e.g., 5, 6)
// Second press: startingID + 2, startingID + 3 (e.g., 7, 8)
// Third press: startingID + 4, startingID + 5 (e.g., 9, 10)
- int currentSkillID1 = m_startingSkillID + (m_currentSkillCycleIndex * 2);
- int currentSkillID2 = currentSkillID1 + 1;
- BMLogger.LogError($"CycleSkillShortcuts: Trying to add skills {currentSkillID1} and {currentSkillID2}");
- // Find and add first skill
- CECSkill pSkill1 = GetPositiveSkillByID(currentSkillID1);
- if (pSkill1 != null)
+ int firstIndex = m_startingSkillID + (m_currentSkillCycleIndex * 8);
+ List skillIDs = new List();
+ for (int i = 0; i < 8; i++)
{
- pSCS.CreateSkillShortcut(0, pSkill1);
- Debug.LogError($"CycleSkillShortcuts: Added skill ID {currentSkillID1} to slot 0");
+ skillIDs.Add(firstIndex + i);
}
- else
+ string skillIDsString = string.Join(", ", skillIDs);
+ BMLogger.LogError($"CycleSkillShortcuts: Trying to add skills {skillIDsString}");
+ for (int i = 0; i < skillIDs.Count; i++)
{
- Debug.LogError($"CycleSkillShortcuts: Skill with ID {currentSkillID1} not found in learned skills");
- int find = 1;
- while (pSkill1 == null && find < 100)
+ int skillID = skillIDs[i];
+ CECSkill pSkill = GetPositiveSkillByID(skillID);
+ if (pSkill != null)
{
- m_startingSkillID++;
- Debug.LogError($"CycleSkillShortcuts: m_startingSkillID {m_startingSkillID} ");
- currentSkillID1 = m_startingSkillID + (m_currentSkillCycleIndex * 2);
- pSkill1 = GetPositiveSkillByID(currentSkillID1);
- find++;
- }
-
- if (pSkill1 != null)
- {
- pSCS.CreateSkillShortcut(0, pSkill1);
+ pSCS.CreateSkillShortcut(i, pSkill);
}
else
{
- Debug.LogError($"CycleSkillShortcuts: Failed to find skill after {find} attempts");
- }
- }
-
- // Find and add second skill
- CECSkill pSkill2 = GetPositiveSkillByID(currentSkillID2);
- if (pSkill2 != null)
- {
- pSCS.CreateSkillShortcut(1, pSkill2);
- Debug.LogError($"CycleSkillShortcuts: Added skill ID {currentSkillID2} to slot 1");
- }
- else
- {
- Debug.LogError($"CycleSkillShortcuts: Skill with ID {currentSkillID2} not found in learned skills");
- int find = 1;
- while (pSkill2 == null && find < 100)
- {
- m_startingSkillID++;
- Debug.LogError($"CycleSkillShortcuts: m_startingSkillID {m_startingSkillID} ");
- currentSkillID2 = m_startingSkillID + (m_currentSkillCycleIndex * 2) + 1;
- pSkill2 = GetPositiveSkillByID(currentSkillID2);
- find++;
- }
-
- if (pSkill2 != null)
- {
- pSCS.CreateSkillShortcut(1, pSkill2);
- }
- else
- {
- Debug.LogError($"CycleSkillShortcuts: Failed to find skill after {find} attempts");
+ Debug.LogError($"CycleSkillShortcuts: Skill with ID {skillID} not found in learned skills");
+ break;
}
}
// Increment cycle index for next press
- m_currentSkillCycleIndex++;
+ ++m_currentSkillCycleIndex;
// Update UI
CDlgQuickBar cDlgQuickBar2 = CECUIManager.Instance?.GetCDlgQuickBar();
@@ -1928,36 +1888,29 @@ namespace BrewMonster
return;
}
- // Calculate how many pairs we can make
- int maxPairs = (skillCount + 1) / 2; // Round up division
+ // Calculate how many groups of 8 we can make
+ int maxGroups = (skillCount + 7) / 8; // Round up division
// Wrap around if we've reached the end
- if (m_currentSkillCycleIndex >= maxPairs)
+ if (m_currentSkillCycleIndex >= maxGroups)
{
m_currentSkillCycleIndex = 0;
}
- // Calculate skill indices for this cycle
- int skillIndex1 = m_currentSkillCycleIndex * 2;
- int skillIndex2 = skillIndex1 + 1;
+ // Calculate starting skill index for this cycle
+ int startSkillIndex = m_currentSkillCycleIndex * 8;
- // Add first skill to slot 0
- if (skillIndex1 < skillCount)
+ // Fill all 8 shortcut slots
+ for (int slotIndex = 0; slotIndex < 8; slotIndex++)
{
- CECSkill pSkill1 = GetPositiveSkillByIndex(skillIndex1);
- if (pSkill1 != null)
+ int skillIndex = startSkillIndex + slotIndex;
+ if (skillIndex < skillCount)
{
- pSCS.CreateSkillShortcut(0, pSkill1);
- }
- }
-
- // Add second skill to slot 1 (if available)
- if (skillIndex2 < skillCount)
- {
- CECSkill pSkill2 = GetPositiveSkillByIndex(skillIndex2);
- if (pSkill2 != null)
- {
- pSCS.CreateSkillShortcut(1, pSkill2);
+ CECSkill pSkill = GetPositiveSkillByIndex(skillIndex);
+ if (pSkill != null)
+ {
+ pSCS.CreateSkillShortcut(slotIndex, pSkill);
+ }
}
}
@@ -1819,9 +1819,9 @@ namespace BrewMonster
#if UNITY_EDITOR
///
- /// Cycles through learned skills by removing all shortcuts and adding 2 new skills to slots 0 and 1.
- /// If m_startingSkillID is set (>0), uses that specific skill ID and the next one (ID+1).
- /// Otherwise, cycles through all learned skills in pairs.
+ /// Cycles through learned skills by removing all shortcuts and adding 8 new skills to slots 0-7.
+ /// If m_startingSkillID is set (>0), uses that specific skill ID and the next 7 (ID+1 through ID+7).
+ /// Otherwise, cycles through all learned skills in groups of 8.
///
public void CycleSkillShortcuts()